# MLinvitroTox

MLinvitroTox performs high-throughput toxicity-based priorizitation of features from nontarget analysis (NTS) of environmental high-resolution mass spectrometry (HRMS) data. 

It is described in a publication that is currently being prepared. 


## A. Project description

The package contains 
- scripts that were used to build the models
- input data to build the models (in `data/input`) and processed data (in `data/processed`)
- modeling results and the models
- a streamlit app to view the results
- scripts for users to run the models on their data


## B. Getting started

Currently, the package is only available on PyPI and can be installed as follows. 

```
pip install mlinvitrotox
```


## C. Example / Usage

Have a look at the [tutorial](https://renkulab.io/projects/expectmine/mlinvitrotox-tutorial). 


## D. Development

If you are interested in the project and the package, please reach out to <lilian.gasser@sdsc.ethz.ch>.
